package com.cemarose.mongodb.config;

import com.mongodb.*;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.data.mongodb.MongoDbFactory;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.SimpleMongoDbFactory;
import org.springframework.stereotype.Component;
@Component
@ConfigurationProperties(prefix = "spring.data.mongodb")
public class MongoConfig {
    /**
     * host主机ip
     */
    private String host;
    /**
     * port端口号
     */
    private Integer port;
    /**
     * mongo地址
     */
    private String uri;

    /**
     * 初始化mongodb客户端
     * @return
     */
    @Bean
    public MongoClient client() {
        return new MongoClient(new ServerAddress(host, port));
    }

    /**
     * 初始化factory
     * @return
     * @throws Exception
     */
    @Bean
    public MongoDbFactory mongoDbFactory() throws Exception{
        String database = new MongoClientURI(uri).getDatabase();
        return new SimpleMongoDbFactory(client(), database);
    }

    /**
     * factory加载到MongoTemplate
     * @param mongoDbFactory
     * @return
     */
    @Bean
    public MongoTemplate mongoTemplete(MongoDbFactory mongoDbFactory){
        return new MongoTemplate(mongoDbFactory);
    }


    //getter and setter
    public String getHost() {
        return host;
    }
    public void setHost(String host) {
        this.host = host;
    }
    public Integer getPort() {
        return port;
    }
    public void setPort(Integer port) {
        this.port = port;
    }
    public String getUri() {
        return uri;
    }
    public void setUri(String uri) {
        this.uri = uri;
    }

}
