package com.cemarose.mongodb.model;

import java.io.Serializable;

import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Transient;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.data.mongodb.core.mapping.Field;

/**
 * 与mongodb中的collection对应
 */
@Document(collection="users")
/**
 * 复合索引，加复合索引后通过复合索引字段查询将大大提高速度。
 */
@CompoundIndexes({
    @CompoundIndex(name = "age_idx", def = "{'name': 1, 'age': -1}")
})
public class Users  implements Serializable{
	private static final long serialVersionid = 1L;
	/**
	 * @Id
	 *
	 * MongoDB默认会为每个document生成一个 _id 属性，作为默认主键，且默认值为ObjectId,可以更改 _id 的值(可为空字符串)，但每个document必须拥有 _id 属性。
	 * 当然，也可以自己设置@Id主键，不过官方建议使用MongoDB自动生成。
	 *
	 * @Indexed
	 *
	 * 声明该字段需要加索引，加索引后以该字段为条件检索将大大提高速度。
	 * 唯一索引的话是@Indexed(unique = true)。
	 * 也可以对数组进行索引，如果被索引的列是数组时，mongodb会索引这个数组中的每一个元素。
	 *
	 *
	 * @Transient
	 *
	 * 被该注解标注的，将不会被录入到数据库中。只作为普通的javaBean属性。
	 *
	 *
	 * @Field
	 *
	 * 代表一个字段，可以不加，不加的话默认以参数名为列名。
	 *
	 *
	 *
	 *
	 */


	/**
	 * mongoId：该字段用于mongodb的"_id"索引
	 * 1、需要@Id注解
	 * 2、取名无所谓，反正在mongodb中最后都会转化为"_id"
	 * 3、定义为String类型，如果定义为Integer可能索引只会是0，会出现key重复导致数据库插不进去的情况；
	 * 4、该类型也是MongoRepository泛型中主键的ID
	 */
	@Indexed
	@Id
	private String mongoId;
	private Integer id;
	private String name;
	@Transient
	private int age;
	@Transient
	private String address;
	public Users(){}

	public String getMongoId() {
		return mongoId;
	}

	public void setMongoId(String mongoId) {
		this.mongoId = mongoId;
	}

	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public int getAge() {
		return age;
	}

	public void setAge(int age) {
		this.age = age;
	}
	
	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	@Override
    public String toString() {
        return String.format("Customer[name='%s', age='%s']", name, age);
    }
}
